@@ -1,4 +1,5 @@
 """Provide a package for python-openei."""
+
 from __future__ import annotations
 
 import datetime
@@ -31,6 +32,7 @@ class InvalidCall(Exception):
     """Exception for invalid library calls."""
 
 
+# pylint: disable=too-many-positional-arguments
 class Rates:
     """Represent OpenEI Rates."""
 
@@ -154,21 +156,39 @@ class Rates:
             _LOGGER.debug("Data updated, results: %s", self._data)
 
     @property
-    def current_rate(self) -> float | None:
-        """Return the current rate."""
+    def current_energy_rate_structure(self) -> int | None:
+        """Return the current rate structure."""
+        return self.rate_structure(datetime.datetime.today(), "energy")
+
+    def rate_structure(self, date, rate_type) -> int | None:
+        """Return the rate structure for a specific date."""
         assert self._data is not None
-        if "energyratestructure" in self._data:
-            weekend = False
-            now = datetime.datetime.today()
-            month = now.month - 1
-            hour = now.hour
-            if now.weekday() > 4:
-                weekend = True
-            table = "energyweekdayschedule"
-            if weekend:
-                table = "energyweekendschedule"
+        if f"{rate_type}ratestructure" in self._data:
+            month = date.month - 1
+            hour = date.hour
+            weekend = date.weekday() > 4
+
+            table = (
+                f"{rate_type}weekendschedule"
+                if weekend
+                else f"{rate_type}weekdayschedule"
+            )
             lookup_table = self._data[table]
             rate_structure = lookup_table[month][hour]
+
+            return rate_structure
+        return None
+
+    @property
+    def current_rate(self) -> float | None:
+        """Return the current rate."""
+        return self.rate(datetime.datetime.today())
+
+    def rate(self, date) -> float | None:
+        """Return the rate for a specific date."""
+        assert self._data is not None
+        rate_structure = self.rate_structure(date, "energy")
+        if rate_structure is not None:
             if self._reading:
                 value = float(self._reading)
                 rate_data = self._data["energyratestructure"][rate_structure]
@@ -184,20 +204,14 @@ class Rates:
     @property
     def current_adjustment(self) -> float | None:
         """Return the current rate."""
+        return self.adjustment(datetime.datetime.today())
+
+    def adjustment(self, date) -> float | None:
+        """Return the rate for a specific date."""
         assert self._data is not None
-        if "energyratestructure" in self._data:
+        rate_structure = self.rate_structure(date, "energy")
+        if rate_structure is not None:
             adj = None
-            weekend = False
-            now = datetime.datetime.today()
-            month = now.month - 1
-            hour = now.hour
-            if now.weekday() > 4:
-                weekend = True
-            table = "energyweekdayschedule"
-            if weekend:
-                table = "energyweekendschedule"
-            lookup_table = self._data[table]
-            rate_structure = lookup_table[month][hour]
             if self._reading:
                 rate_data = self._data["energyratestructure"][rate_structure]
                 if "adj" in rate_data[-1]:
@@ -212,21 +226,18 @@ class Rates:
     def monthly_tier_rate(self) -> float | None:
         """Return tier rate.
 
+        Requires the monthy accumulative meter reading.
+        """
+        return self.tier_rate_for_month(datetime.datetime.today())
+
+    def tier_rate_for_month(self, date) -> float | None:
+        """Return tier rate for a specific month.
+
         Requires the monthy accumulative meter reading.
         """
         assert self._data is not None
-        if "energyratestructure" in self._data:
-            weekend = False
-            now = datetime.datetime.today()
-            month = now.month - 1
-            hour = now.hour
-            if now.weekday() > 4:
-                weekend = True
-            table = "energyweekdayschedule"
-            if weekend:
-                table = "energyweekendschedule"
-            lookup_table = self._data[table]
-            rate_structure = lookup_table[month][hour]
+        rate_structure = self.rate_structure(date, "energy")
+        if rate_structure is not None:
             if self._reading:
                 value = float(self._reading)
                 rate_data = self._data["energyratestructure"][rate_structure]
@@ -257,44 +268,28 @@ class Rates:
     @property
     def current_demand_rate(self) -> float | None:
         """Return the current rate."""
+        return self.demand_rate(datetime.datetime.today())
+
+    def demand_rate(self, date) -> float | None:
+        """Return the rate for a specific date."""
         assert self._data is not None
-        if "demandratestructure" in self._data:
-            weekend = False
-            now = datetime.datetime.today()
-            month = now.month - 1
-            hour = now.hour
-            if now.weekday() > 4:
-                weekend = True
-            table = "demandweekdayschedule"
-            if weekend:
-                table = "demandweekendschedule"
-
-            lookup_table = self._data[table]
-            rate_structure = lookup_table[month][hour]
-
+        rate_structure = self.rate_structure(date, "demand")
+        if rate_structure is not None:
             rate = self._data["demandratestructure"][rate_structure][0]["rate"]
-
             return rate
         return None
 
     @property
     def current_demand_adjustment(self) -> float | None:
         """Return the current rate."""
-        assert self._data is not None
-        if "demandratestructure" in self._data:
-            adj = None
-            weekend = False
-            now = datetime.datetime.today()
-            month = now.month - 1
-            hour = now.hour
-            if now.weekday() > 4:
-                weekend = True
-            table = "demandweekdayschedule"
-            if weekend:
-                table = "demandweekendschedule"
+        return self.demand_adjustment(datetime.datetime.today())
 
-            lookup_table = self._data[table]
-            rate_structure = lookup_table[month][hour]
+    def demand_adjustment(self, date) -> float | None:
+        """Return the rate for a specific date."""
+        assert self._data is not None
+        rate_structure = self.rate_structure(date, "demand")
+        if rate_structure is not None:
+            adj = None
 
             adj_data = self._data["demandratestructure"][rate_structure][0]
             if "adj" in adj_data:
